/*
 * Copyright (c) 2006, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.wso2.registry.web.actions;

import org.wso2.registry.ActionConstants;
import org.wso2.registry.RegistryException;
import org.wso2.registry.RegistryConstants;
import org.wso2.registry.secure.SecureRegistry;
import org.wso2.usermanager.AccessControlAdmin;
import org.wso2.usermanager.Realm;
import org.wso2.usermanager.UserManagerException;

import javax.servlet.http.HttpServletRequest;

public class MassRoleAuthorizationAction extends AbstractRegistryAction {

    private String resourcePath;
    private String permissionString;

    public void execute(HttpServletRequest request) throws RegistryException {

        setRequest(request);

        SecureRegistry secureRegistry = (SecureRegistry) getRegistry();
        Realm realm = secureRegistry.getUserRealm();

        AccessControlAdmin accessControlAdmin = null;
        try {
            accessControlAdmin = realm.getAccessControlAdmin();
        } catch (UserManagerException e) {
            String msg = "Couldn't get access control admin for changing authorizations. Caused by: " + e.getMessage();
            throw new RegistryException(msg);
        }

        try {

            String[] rolePermissions = permissionString.split("1");
            for (int i = 0; i < rolePermissions.length; i++) {

                if (rolePermissions[i].trim().length() == 0) {
                    continue;
                }

                String[] permissions = rolePermissions[i].split("2");
                String permRole = permissions[0];

                if (!permRole.equals(RegistryConstants.ADMIN_ROLE)) {
                    accessControlAdmin.clearRoleAuthorization(permRole, resourcePath, ActionConstants.GET);
                    accessControlAdmin.clearRoleAuthorization(permRole, resourcePath, ActionConstants.PUT);
                    accessControlAdmin.clearRoleAuthorization(permRole, resourcePath, ActionConstants.DELETE);
                }

                for (int j = 1; j < permissions.length; j++) {
                    String[] permission = permissions[j].split("3");

                    String action = permission[0];
                    String checked = permission[1];

                    if (action.equals("ra")) {
                        if (checked.equals("true")) {
                            accessControlAdmin.authorizeRole(permRole, resourcePath, ActionConstants.GET);
                        }
                    } else if (action.equals("rd")) {
                        if (checked.equals("true")) {
                            accessControlAdmin.denyRole(permRole, resourcePath, ActionConstants.GET);
                        }
                    } else if (action.equals("wa")) {
                        if (checked.equals("true")) {
                            accessControlAdmin.authorizeRole(permRole, resourcePath, ActionConstants.PUT);
                        }
                    } else if (action.equals("wd")) {
                        if (checked.equals("true")) {
                            accessControlAdmin.denyRole(permRole, resourcePath, ActionConstants.PUT);
                        }
                    } else if (action.equals("da")) {
                        if (checked.equals("true")) {
                            accessControlAdmin.authorizeRole(permRole, resourcePath, ActionConstants.DELETE);
                        }
                    } else if (action.equals("dd")) {
                        if (checked.equals("true")) {
                            accessControlAdmin.denyRole(permRole, resourcePath, ActionConstants.DELETE);
                        }
                    }
                }
            }
        } catch (UserManagerException e) {
            String msg = "Couldn't set authorizations. Caused by: " + e.getMessage();
            throw new RegistryException(msg);
        }
    }

    public String getResourcePath() {
        return resourcePath;
    }

    public void setResourcePath(String resourcePath) {
        this.resourcePath = resourcePath;
    }

    public String getPermissionString() {
        return permissionString;
    }

    public void setPermissionString(String permissionString) {
        this.permissionString = permissionString;
    }
}
